@@ -1,13 +1,13 @@
-
 import sys
 import threading
 import time
-import traceback
 from functools import wraps
 
-from qtpy.QtCore import QTimer, Signal, QThread, QObject, QEvent, QCoreApplication, Qt
-from qtpy.QtWidgets import QApplication
 from loguru import logger
+from qtpy.QtCore import QTimer, Signal, QThread, QObject, QEvent, QCoreApplication
+from qtpy.QtWidgets import QApplication
+
+from tsuchinoko.utils.coverage import coverage_resolve_trace
 
 
 def log_error(exception: Exception, value=None, tb=None, **kwargs):
@@ -124,12 +124,14 @@ class QThreadFuture(QThread):
         if self.timeout:
             self._timeout_timer = QTimer.singleShot(self.timeout, self.cancel)
 
+    @coverage_resolve_trace
     def run(self, *args, **kwargs):
         """
         Do not call this from the main thread; you're probably looking for start()
         """
         # if self.threadkey:
         #     threading.current_thread().name = self.threadkey
+
         threading.current_thread().name = self.name
         self.cancelled = False
         self.exception = None
@@ -160,9 +162,9 @@ class QThreadFuture(QThread):
             self.exception = ex
             self.sigExcept.emit(ex)
             logger.error(f"Error in thread: "
-                    f'Method: {getattr(self.method, "__name__", "UNKNOWN")}\n'
-                    f"Args: {self.args}\n"
-                    f"Kwargs: {self.kwargs}",)
+                         f'Method: {getattr(self.method, "__name__", "UNKNOWN")}\n'
+                         f"Args: {self.args}\n"
+                         f"Kwargs: {self.kwargs}", )
             log_error(ex)
         else:
             self.sigFinished.emit()
